Douglas.no Hjelp og kundeservice

# Kontakt

### Meny

- Spørsmål og svar
- Handle på douglas.no
- Fordelsprogram
- Din bestilling
- Min Douglas
- Betaling
- Frakt og levering
- Personvern
- Rabatter og tilbud
- Om Douglas
- Vilkår og betingelser
- Impressum
- Kontakt

#### Kontakt

Finner du ikke svar på spørsmålet ditt? Vi hjelper deg gjerne. Kontakt vår kundeservice.

#### Kundeservice

##### Våre åpningstider er:

Mandag - Fredag 10.00 - 19.00
Lørdag 10.00 - 18.00

##### Kontakt Kundeservie:

Du treffer oss om du fyller inn Kontaktskjema eller skriver en e-post, inkludert ordrenummer, kundenummer og ditt telefonnummer direkte til:
kundeservice@douglas.no

Du kan også nå Kundeservice på tlf.: 815 24 711

Til toppen

#### Kontaktskjema

Sender du inn et spørsmål utenfor åpningstidene vil vi svare deg i løpet av førstkommende arbeidsdag.

Navn

E-post

Emne

Din melding

Til toppen